@@ -3,7 +3,7 @@ Generates a dictionary of ANSI escape codes.
 
 http://en.wikipedia.org/wiki/ANSI_escape_code
 
-Uses colorama as an optional dependancy to support color on Windows
+Uses colorama as an optional dependency to support color on Windows
 """
 
 try:
@@ -11,7 +11,7 @@ try:
 except ImportError:
     pass
 else:
-    colorama.init()
+    colorama.init(strip=False)
 
 __all__ = ('escape_codes', 'parse_colors')
 
